Struct googapis::google::cloud::security::privateca::v1::CertificateConfig [−][src]
pub struct CertificateConfig {
pub subject_config: Option<SubjectConfig>,
pub x509_config: Option<X509Parameters>,
pub public_key: Option<PublicKey>,
}Expand description
A [CertificateConfig][google.cloud.security.privateca.v1.CertificateConfig] describes an X.509 certificate or CSR that is to be created, as an alternative to using ASN.1.
Fields
subject_config: Option<SubjectConfig>Required. Specifies some of the values in a certificate that are related to the subject.
x509_config: Option<X509Parameters>Required. Describes how some of the technical X.509 fields in a certificate should be populated.
public_key: Option<PublicKey>Optional. The public key that corresponds to this config. This is, for example, used when issuing [Certificates][google.cloud.security.privateca.v1.Certificate], but not when creating a self-signed [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority] or [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority] CSR.